import urllib

import requests
from django.urls import reverse


class RemoteTestMixin:

    # MFA
    def mfa_activate(self, method_name, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'mfa-activate',
            args=(method_name,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def mfa_deactivate(self, method_name):
        self.token_refresh()
        endpoint = reverse(
            'mfa-deactivate',
            args=(method_name,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def mfa_activate_confirm(self, method_name, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'mfa-activate-confirm',
            args=(method_name,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def mfa_regenerate_codes(self, method_name, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'mfa-regenerate-codes',
            args=(method_name,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def mfa_login(self, username, password):
        post_dict = {'username': username, 'password': password}
        endpoint = reverse('generate-code-jwt')
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, json=post_dict)
        if resp.status_code == 200:
            if "access" in resp.json():
                self.jwt = resp.json()['access']
                self.refresh = resp.json()['refresh']
            else:
                self.ephemeral_token = resp.json()['ephemeral_token']
                self.mfa_method = resp.json()['method']
            self.rprint(resp)
            return resp
        self.rprint(resp)
        return resp

    def mfa_login_second_step(self, ephemeral_token, code):
        post_dict = {'ephemeral_token': ephemeral_token, 'code': code}
        endpoint = reverse('generate-token-jwt')
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, json=post_dict)
        if resp.status_code == 200:
            self.jwt = resp.json()['access']
            self.refresh = resp.json()['refresh']
            self.rprint(resp)
            return resp
        self.rprint(resp)
        return resp

    def mfa_change_primary_method(self, method, code):
        self.token_refresh()
        post_dict = {"method": method, "code": code}
        endpoint = reverse('mfa-change-primary-method')
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, json=post_dict)
        self.rprint(resp)
        return resp

    def mfa_config(self):
        self.token_refresh()
        endpoint = reverse('mfa-config-info')
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def mfa_list_user_active_methods(self):
        self.token_refresh()
        endpoint = reverse('mfa-list-user-active-methods')
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
