# -*- coding: utf-8 -*-
import io
import logging
from typing import Union

from django.conf import settings
from django.http import HttpResponse
from django.utils.module_loading import import_string
from trench.backends.application import ApplicationMessageDispatcher
from trench.responses import DispatchResponse, FailedDispatchResponse

qrcode_generator = import_string(settings.THX_MFA_GENERATE_QRCODE_FUNCTION)


class QRCodeApplicationMessageDispatcher(ApplicationMessageDispatcher):
    def dispatch_message(self) -> Union[DispatchResponse, HttpResponse]:
        try:
            qr_link = self._create_qr_link(self._mfa_method.user)
            buffer = io.BytesIO()
            qrcode_generator(qr_link, buffer)
            buffer.seek(0)
            return HttpResponse(buffer.read(), content_type="image/png")
        except Exception as cause:
            logging.error(cause, exc_info=True)
            return FailedDispatchResponse(details=str(cause))
