# -*- coding: utf-8 -*-
from django.db import transaction
from trench.command import deactivate_mfa_method
from trench.command.deactivate_mfa_method import deactivate_mfa_method_command
from trench.utils import get_mfa_model


@transaction.atomic()
def patched_deactivate_mfa_method_command(mfa_method_name: str, user_id: int) -> None:
    """If a method is deactivated, then it should not be primary."""
    deactivate_mfa_method_command(mfa_method_name, user_id)
    mfa_model = get_mfa_model()
    mfa_model.objects.filter(user_id=user_id, name=mfa_method_name, is_active=False).update(is_primary=False)


def monkey_patch_deactivate_mfa_method_command():
    deactivate_mfa_method.deactivate_mfa_method_command = patched_deactivate_mfa_method_command


def monkey_patch_views():
    from trench import views
    from trench.views import jwt

    from thx.mfa.views import (
        MFAFirstStepJWTView, MFAMethodActivationView, MFAMethodConfirmActivationView, MFAMethodDeactivationView,
    )

    views.MFAMethodActivationView = MFAMethodActivationView
    views.MFAMethodConfirmActivationView = MFAMethodConfirmActivationView
    views.MFAMethodDeactivationView = MFAMethodDeactivationView

    jwt.MFAFirstStepJWTView = MFAFirstStepJWTView
